@@ -22,8 +22,11 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+from __future__ import absolute_import
+
 import sys
 
-if __name__ == '__main__':
-    from bpython.curtsies import main
+if __name__ == "__main__":
+    from .curtsies import main
+
     sys.exit(main())
