@@ -11,27 +11,26 @@ from pygments.lexers import get_lexer_by_name
 
 from bpython.curtsiesfrontend.parse import parse
 from bpython.repl import Interpreter as ReplInterpreter
-from bpython.config import getpreferredencoding
 
 
 default_colors = {
-    Generic.Error: 'R',
-    Keyword: 'd',
-    Name: 'c',
-    Name.Builtin: 'g',
-    Comment: 'b',
-    String: 'm',
-    Error: 'r',
-    Literal: 'd',
-    Number: 'M',
-    Number.Integer: 'd',
-    Operator: 'd',
-    Punctuation: 'd',
-    Token: 'd',
-    Whitespace: 'd',
-    Token.Punctuation.Parenthesis: 'R',
-    Name.Function: 'd',
-    Name.Class: 'd'
+    Generic.Error: "R",
+    Keyword: "d",
+    Name: "c",
+    Name.Builtin: "g",
+    Comment: "b",
+    String: "m",
+    Error: "r",
+    Literal: "d",
+    Number: "M",
+    Number.Integer: "d",
+    Operator: "d",
+    Punctuation: "d",
+    Token: "d",
+    Whitespace: "d",
+    Token.Punctuation.Parenthesis: "R",
+    Name.Function: "d",
+    Name.Class: "d",
 }
 
 
@@ -49,11 +48,11 @@ class BPythonFormatter(Formatter):
     def __init__(self, color_scheme, **options):
         self.f_strings = {}
         for k, v in iteritems(color_scheme):
-            self.f_strings[k] = '\x01%s' % (v,)
-        Formatter.__init__(self, **options)
+            self.f_strings[k] = "\x01%s" % (v,)
+        super(BPythonFormatter, self).__init__(**options)
 
     def format(self, tokensource, outfile):
-        o = ''
+        o = ""
 
         for token, text in tokensource:
             while token not in self.f_strings:
@@ -69,7 +68,7 @@ class Interp(ReplInterpreter):
         We include an argument for the outfile to pass to the formatter for it
         to write to.
         """
-        ReplInterpreter.__init__(self, locals, encoding)
+        super(Interp, self).__init__(locals, encoding)
 
         # typically changed after being instantiated
         # but used when interpreter used corresponding REPL
@@ -83,29 +82,30 @@ class Interp(ReplInterpreter):
         self.outfile = self
 
     def writetb(self, lines):
-        tbtext = ''.join(lines)
+        tbtext = "".join(lines)
         lexer = get_lexer_by_name("pytb")
         self.format(tbtext, lexer)
         # TODO for tracebacks get_lexer_by_name("pytb", stripall=True)
 
     def format(self, tbtext, lexer):
         traceback_informative_formatter = BPythonFormatter(default_colors)
-        traceback_code_formatter = BPythonFormatter({Token: ('d')})
+        traceback_code_formatter = BPythonFormatter({Token: ("d")})
         tokens = list(lexer.get_tokens(tbtext))
 
         no_format_mode = False
         cur_line = []
         for token, text in tokens:
-            if text.endswith('\n'):
+            if text.endswith("\n"):
                 cur_line.append((token, text))
                 if no_format_mode:
                     traceback_code_formatter.format(cur_line, self.outfile)
                     no_format_mode = False
                 else:
-                    traceback_informative_formatter.format(cur_line,
-                                                           self.outfile)
+                    traceback_informative_formatter.format(
+                        cur_line, self.outfile
+                    )
                 cur_line = []
-            elif text == '    ' and cur_line == []:
+            elif text == "    " and cur_line == []:
                 no_format_mode = True
                 cur_line.append((token, text))
             else:
