@@ -13,13 +13,13 @@ except ImportError:
 from bpython.translations import init
 from bpython._py3compat import py3
 from six.moves import builtins
+import os
 
 
 class FixLanguageTestCase(unittest.TestCase):
-
     @classmethod
     def setUpClass(cls):
-        init(languages=['en'])
+        init(languages=["en"])
 
 
 class MagicIterMock(mock.MagicMock):
@@ -32,4 +32,7 @@ class MagicIterMock(mock.MagicMock):
 
 def builtin_target(obj):
     """Returns mock target string of a builtin"""
-    return '%s.%s' % (builtins.__name__, obj.__name__)
+    return "%s.%s" % (builtins.__name__, obj.__name__)
+
+
+TEST_CONFIG = os.path.join(os.path.dirname(__file__), "test.config")
